@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2009 Floriano Scioscia.
+ * Copyright (C) 2009, 2010 Floriano Scioscia.
  *
  * This file is part of 100 Boxes.
  *
@@ -30,6 +30,30 @@
 void sound_init(int *argc, char **argv[]);
 
 /**
- * Play a sound file
+ * Play a single sound file
  */
-int play_sound(const gchar *path);
+gint play_sound(const gchar *path);
+
+/**
+ * Add a sound file to the stock of sounds that can be
+ * played by the application.
+ */
+GList* add_stock_sound(GList *stock, const gchar *name, const gchar *path, gint *err);
+
+/**
+ * Play a sound from the stock.
+ */
+gint play_stock_sound(GList *stock, const gchar *name);
+
+/**
+ * Remove a sound from the stock
+ */
+void remove_stock_sound(GList *stock, const gchar *name);
+
+/**
+ * Completely erase the stock. It is important to call
+ * this function when finished using a sound stock,
+ * in order to avoid memory leaks.
+ */
+void clear_stock(GList *stock);
+
